@@ -1,9 +1,9 @@
 import datetime
 import logging
 
-from rumpy.client import FullNode, HttpRequest, LightNode, MiniNode
+from rumpy.client import FullNode, HttpRequest, LightNode
 
-__version__ = "0.8.2"
+__version__ = "0.8.3"
 __author__ = "liujuanjuan1984"
 
 # Set default logging handler to avoid "No handler found" warnings.
